require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spuserprofileproperty',
  dscmeta_resource_friendly_name: 'SPUserProfileProperty',
  dscmeta_resource_name: 'MSFT_SPUserProfileProperty',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.2.0',
  docs: 'The DSC SPUserProfileProperty resource type.
         Automatically generated from version 5.2.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'The description of the property',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_type: {
      type: "Optional[Enum['Big Integer', 'Binary', 'Boolean', 'Date', 'DateNoYear', 'Date Time', 'Email', 'Float', 'HTML', 'Integer', 'Person', 'String (Single Value)', 'String (Multi Value)', 'TimeZone', 'Unique Identifier', 'URL']]",
      desc: 'The type of the property',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_privacysetting: {
      type: "Optional[Enum['Public', 'Contacts', 'Organization', 'Manager', 'Private']]",
      desc: 'The privacy setting for the property',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: 'Optional[String]',
      desc: 'The display name of the property',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_userprofileservice: {
      type: 'String',
      desc: 'The name of the user profile service application',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_isalias: {
      type: 'Optional[Boolean]',
      desc: 'Is this field an alias that can be used to refer to a user by',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_termstore: {
      type: 'Optional[String]',
      desc: 'The name of the term store to look up managed terms from',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'The internal name of the user profile property',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_useroverrideprivacy: {
      type: 'Optional[Boolean]',
      desc: 'Can users override the default privacy policy',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present if the property should exist, absent if it should be removed',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_termgroup: {
      type: 'Optional[String]',
      desc: 'The name of the term store group that terms are in for this field',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_policysetting: {
      type: "Optional[Enum['Mandatory', 'Optin', 'Optout', 'Disabled']]",
      desc: 'The policy setting to apply to the property',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_propertymappings: {
      type: "Optional[Array[Struct[{
              propertyname => String,
              connectionname => String,
              direction => Enum['Import', 'Export'],
            }]]]",
      desc: 'The details about the property mapping',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPUserProfilePropertyMapping[]',
      mof_is_embedded: true,
    },
    dsc_iseventlog: {
      type: 'Optional[Boolean]',
      desc: 'Is this field used for event logging',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_isvisibleoneditor: {
      type: 'Optional[Boolean]',
      desc: 'Is this field visible when editing a users profile, or hidden from editing',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_isvisibleonviewer: {
      type: 'Optional[Boolean]',
      desc: 'Is this field visible when viewing a users profile',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_issearchable: {
      type: 'Optional[Boolean]',
      desc: 'Is this field able to be searched upon',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_displayorder: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The display order to put the property in to the list at',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_isusereditable: {
      type: 'Optional[Boolean]',
      desc: 'Is this field able to be edited by a user, or only an administrator',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_length: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The length of the field',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_isreplicable: {
      type: 'Optional[Boolean]',
      desc: 'Is this field replicated to Microsoft SharePoint Foundation 2010 sites',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_termset: {
      type: 'Optional[String]',
      desc: 'The name of the term set to allow values to be selected from',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
