require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spwebapppermissions',
  dscmeta_resource_friendly_name: 'SPWebAppPermissions',
  dscmeta_resource_name: 'MSFT_SPWebAppPermissions',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.2.0',
  docs: 'The DSC SPWebAppPermissions resource type.
         Automatically generated from version 5.2.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_allpermissions: {
      type: 'Optional[Boolean]',
      desc: 'Set all permissions',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_listpermissions: {
      type: "Optional[Array[Enum['Manage Lists', 'Override List Behaviors', 'Add Items', 'Edit Items', 'Delete Items', 'View Items', 'Approve Items', 'Open Items', 'View Versions', 'Delete Versions', 'Create Alerts', 'View Application Pages']]]",
      desc: 'List permissions that need to be configured',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_personalpermissions: {
      type: "Optional[Array[Enum['Manage Personal Views', 'Add/Remove Personal Web Parts', 'Update Personal Web Parts']]]",
      desc: 'Personal permissions that need to be configured',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_webappurl: {
      type: 'String',
      desc: 'The url of the web application',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitepermissions: {
      type: "Optional[Array[Enum['Manage Permissions', 'View Web Analytics Data', 'Create Subsites', 'Manage Web Site', 'Add and Customize Pages', 'Apply Themes and Borders', 'Apply Style Sheets', 'Create Groups', 'Browse Directories', 'Use Self-Service Site Creation', 'View Pages', 'Enumerate Permissions', 'Browse User Information', 'Manage Alerts', 'Use Remote Interfaces', 'Use Client Integration Features', 'Open', 'Edit Personal User Information']]]",
      desc: 'Site permissions that need to be configured',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
